Skip to main contentModule model
Source - EnumDef
- All user-defined enum types found in the scanned source files.
Needed for generating corresponding TypeScript union types.
- EnumVariant
- A single variant of a Rust enum.
- FieldDef
- A single field in a struct or struct variant.
- Manifest
- Complete manifest of all discovered RPC metadata from a scan.
- Procedure
- Metadata for a single RPC procedure extracted from a source file.
- RustType
- A single Rust type reference extracted from source code.
- StructDef
- All user-defined struct types found in the scanned source files.
Needed for generating corresponding TypeScript interfaces.
- UnknownRenameRule
- Error returned when parsing an unknown
rename_all rule string.
- EnumTagging
- Serde enum tagging strategy.
- ProcedureKind
- The kind of RPC procedure, determined by the macro attribute.
- RenameRule
- Serde
rename_all naming convention. - VariantKind
- The shape of an enum variant’s data.